==> haskell-edit-distance-0.2.2.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: edit-distance
version: 0.2.2.1
id: edit-distance-0.2.2.1-1mVwuMEjztjEsqcnGcpkR9
key: edit-distance-0.2.2.1-1mVwuMEjztjEsqcnGcpkR9
license: BSD3
copyright: (c) 2008-2013 Maximilian Bolinbroke
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: http://github.com/phadej/edit-distance
synopsis: Levenshtein and restricted Damerau-Levenshtein edit distances
description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.
category: Algorithms
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules:
    Text.EditDistance
hidden-modules: Text.EditDistance.EditCosts
                Text.EditDistance.SquareSTUArray Text.EditDistance.STUArray
                Text.EditDistance.Bits Text.EditDistance.MonadUtilities
                Text.EditDistance.ArrayUtilities
abi: de6136326ff8b963f409543cfacc6bfb
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/edit-distance-0.2.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/edit-distance-0.2.2.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/edit-distance-0.2.2.1
hs-libraries: HSedit-distance-0.2.2.1-1mVwuMEjztjEsqcnGcpkR9
depends:
    array-0.5.1.1 base-4.9.0.0 containers-0.5.7.1
    random-1.1-54KmMHXjttlERYcr1mvsAe
haddock-interfaces: /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock
haddock-html: /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edit-distance-0.2.2.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: edit-distance
version: 0.2.2.1
id: edit-distance-0.2.2.1-6t5gSPdZR9l59S7jfGb06u
key: edit-distance-0.2.2.1-6t5gSPdZR9l59S7jfGb06u
license: BSD3
copyright: (c) 2008-2013 Maximilian Bolinbroke
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: http://github.com/phadej/edit-distance
synopsis: Levenshtein and restricted Damerau-Levenshtein edit distances
description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.
category: Algorithms
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules:
    Text.EditDistance
hidden-modules: Text.EditDistance.EditCosts
                Text.EditDistance.SquareSTUArray Text.EditDistance.STUArray
                Text.EditDistance.Bits Text.EditDistance.MonadUtilities
                Text.EditDistance.ArrayUtilities
abi: 786560443106b83dbd39f61783f4e663
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/edit-distance-0.2.2.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/edit-distance-0.2.2.1
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/edit-distance-0.2.2.1
hs-libraries: HSedit-distance-0.2.2.1-6t5gSPdZR9l59S7jfGb06u
depends:
    array-0.5.1.1 base-4.9.1.0 containers-0.5.7.1
    random-1.1-9tceXaeYIMZ4JrKq20Egog
haddock-interfaces: /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock
haddock-html: /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
